@@ -35,15 +35,6 @@ backup_local(phost_t host[], int which, struct argument_t *arg)
 	size_t l; unsigned int newscheme; 
 	int transfer = 0;
 
-	/* run the prerun script - do this way early. People like to mount their
-	 * backup filesystem before doing anything */
-	if ( host[which]->prerun != NULL ) {
-		if ( hdup_runpre(host[which], scheme, arg->scheme, NULL) != 0 ) {
-			SYSLOG_HW("%s","Prescript executed with errors");
-			FATAL("%s: %s",host[which]->name, "Prescript executed with errors");
-		}
-	}
-
 	/* setup the directory */
 	if ( host[which]->remote == NULL ) 
 		hdup_setup(host, which);
@@ -688,6 +679,15 @@ out:
 		LOGDEBUG("chunk %s", host[which]->chunksize);
 	}
 
+	/* run the prerun script - do this way early. People like to mount their
+	 * backup filesystem before doing anything */
+	if ( host[which]->prerun != NULL ) {
+		if ( hdup_runpre(host[which], scheme, arg.scheme, NULL) != 0 ) {
+			SYSLOG_HW("%s","Prescript executed with errors");
+			FATAL("%s: %s",host[which]->name, "Prescript executed with errors");
+		}
+	}
+
 	/* setup the overview status message */
 	hdup_overview(NULL, NULL);
 	hdup_overview("Hdup version", VERSION);
